set -e

CONFIGURATION=${CONFIG:="Release"}

########################################################################
# CLEAN old outputs
########################################################################
rm -r -f *.xcarchive
rm -f *.IPA
rm -f libRxAutomationUni_*.a

########################################################################
# Ceck prequesites
########################################################################
echo "Checking build prequesites"
if [ -f ./LibRxAutomationUni.a ]
then
	echo "LibRxAutomationUni found" 
else
	echo "LibRxAutomation not found. Please build Automation probject before building RxBrowser."
fi

########################################################################
# Ensure latest lib gets used
########################################################################
# We sometimes had the issue that during the build an old RxAutomationUni 
# lib was used for some reason (we were never able to resolve the issue)
# as XCode's build output is not verbose enough (i assume there was some
# system setting etc that appended some invalid search path etc. that 
# caused that an old lib was found instead of the current lib
# But as it is essential that the command line build definitely uses the 
# latest version, we use the following few lines and an explicit 
# linker flag to ensure that the library lying around in ./ is used.
UUID=$(uuidgen)
RND_AUTOMATION_NAME="libRxAutomationUni_${UUID}.a"
cp ./libRxAutomationUni.a ${RND_AUTOMATION_NAME}

########################################################################
# Create unsigned archive
########################################################################
echo "Generating unsinged archive"
xcodebuild -project RxBrowser.xcodeproj -scheme RxBrowser archive -archivePath ./RxBrowser.xcarchive OTHER_LDFLAGS="-ObjC -all_load ./${RND_AUTOMATION_NAME}" 2>&1

########################################################################
# Create the signed IPA archive
########################################################################
xcodebuild -exportArchive -exportFormat ipa -archivePath ./RxBrowser.xcarchive -exportPath ./RxBrowser.IPA -exportProvisioningProfile iOSRxBrowserInHouseDistribution2014
